pub struct LateParamRegion<'db> {
pub scope: SolverDefId<'db>,
pub bound_region: BoundRegion<'db>,
}Expand description
Represents a liberated late-bound function lifetime parameter.
This denotes some region at least as big as scope. It is similar to a placeholder region
created when entering a binder, except it always lives in the root universe.
Fields
scope: SolverDefId<'db>bound_region: BoundRegion<'db>Trait Implementations
Sourceimpl<'db> Clone for LateParamRegion<'db>
impl<'db> Clone for LateParamRegion<'db>
Sourcefn clone(&self) -> LateParamRegion<'db>
fn clone(&self) -> LateParamRegion<'db>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LateParamRegion<'_>
impl Debug for LateParamRegion<'_>
Sourceimpl<'db, __V: WorldExposer> GenericTypeVisitable<__V> for LateParamRegion<'db>
impl<'db, __V: WorldExposer> GenericTypeVisitable<__V> for LateParamRegion<'db>
fn generic_visit_with(&self, __visitor: &mut __V)
Sourceimpl<'db> Hash for LateParamRegion<'db>
impl<'db> Hash for LateParamRegion<'db>
Sourceimpl<'db> PartialEq for LateParamRegion<'db>
impl<'db> PartialEq for LateParamRegion<'db>
Sourcefn eq(&self, other: &LateParamRegion<'db>) -> bool
fn eq(&self, other: &LateParamRegion<'db>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<'db> Copy for LateParamRegion<'db>
impl<'db> Eq for LateParamRegion<'db>
impl<'db> StructuralPartialEq for LateParamRegion<'db>